summaryrefslogtreecommitdiff
path: root/sc/inc/address.hxx
diff options
context:
space:
mode:
authorJan Holesovsky <kendy@suse.cz>2011-03-18 15:33:40 +0100
committerJan Holesovsky <kendy@suse.cz>2011-03-18 15:33:40 +0100
commite6064484fae8aa2797f86c68e9a8d23d2e213367 (patch)
treedb2f4d140efca43ab01dee4fc053fff0829d106b /sc/inc/address.hxx
parent9e0a09e89c38774dd1af902387a8b25de158b634 (diff)
parent378c75a798c8baa34cb26e7f07fe28cb5ee2a85f (diff)
Merge remote-tracking branch 'origin/integration/dev300_m101'
Conflicts: chart2/source/controller/main/UndoManager.cxx chart2/source/tools/RegressionCurveHelper.cxx sc/inc/address.hxx sc/inc/attrib.hxx sc/inc/bigrange.hxx sc/inc/callform.hxx sc/inc/cell.hxx sc/inc/chartarr.hxx sc/inc/chartlis.hxx sc/inc/chgtrack.hxx sc/inc/collect.hxx sc/inc/compiler.hxx sc/inc/detdata.hxx sc/inc/document.hxx sc/inc/fillinfo.hxx sc/inc/olinetab.hxx sc/inc/prnsave.hxx sc/inc/queryparam.hxx sc/inc/sc.hrc sc/inc/scabstdlg.hxx sc/inc/table.hxx sc/inc/validat.hxx sc/inc/zforauto.hxx sc/source/core/data/documen2.cxx sc/source/core/data/document.cxx sc/source/core/data/table1.cxx sc/source/core/tool/address.cxx sc/source/core/tool/token.cxx sc/source/filter/excel/frmbase.cxx sc/source/filter/excel/impop.cxx sc/source/filter/excel/xename.cxx sc/source/filter/inc/formel.hxx sc/source/filter/inc/xename.hxx sc/source/filter/xml/xmlexprt.cxx sc/source/filter/xml/xmlnexpi.cxx sc/source/filter/xml/xmlnexpi.hxx sc/source/ui/dbgui/filtdlg.cxx sc/source/ui/inc/docfunc.hxx sc/source/ui/inc/namedlg.hxx sc/source/ui/namedlg/namedlg.cxx sc/source/ui/src/namedlg.src
Diffstat (limited to 'sc/inc/address.hxx')
-rw-r--r--sc/inc/address.hxx34
1 files changed, 14 insertions, 20 deletions
diff --git a/sc/inc/address.hxx b/sc/inc/address.hxx
index d7e00d17f5d6..96842785c8f3 100644
--- a/sc/inc/address.hxx
+++ b/sc/inc/address.hxx
@@ -133,12 +133,6 @@ const SCROW SCROWS64K = 65536;
// === old stuff defines =====================================================
-#ifdef WIN
-// Under 16bit Windows rows still had to be limited to 8192.
-// (define manually for testing)
-#define SC_LIMIT_ROWS
-#endif
-
#define MAXROW_30 8191
#define MAXROW_40 31999
@@ -323,15 +317,15 @@ public:
inline void GetVars( SCCOL& nColP, SCROW& nRowP, SCTAB& nTabP ) const
{ nColP = nCol; nRowP = nRow; nTabP = nTab; }
- SC_DLLPUBLIC USHORT Parse( const String&, ScDocument* = NULL,
+ SC_DLLPUBLIC sal_uInt16 Parse( const String&, ScDocument* = NULL,
const Details& rDetails = detailsOOOa1,
ExternalInfo* pExtInfo = NULL,
const ::com::sun::star::uno::Sequence<
const ::com::sun::star::sheet::ExternalLinkInfo > * pExternalLinks = NULL );
- SC_DLLPUBLIC void Format( rtl::OUString&, USHORT = 0, ScDocument* = NULL,
+ SC_DLLPUBLIC void Format( rtl::OUString&, sal_uInt16 = 0, ScDocument* = NULL,
const Details& rDetails = detailsOOOa1) const;
- SC_DLLPUBLIC void Format( String&, USHORT = 0, ScDocument* = NULL,
+ SC_DLLPUBLIC void Format( String&, sal_uInt16 = 0, ScDocument* = NULL,
const Details& rDetails = detailsOOOa1) const;
// The document for the maximum defined sheet number
@@ -346,7 +340,7 @@ public:
inline size_t hash() const;
/// "A1" or "$A$1" or R1C1 or R[1]C[1]
- String GetColRowString( bool bAbsolute = FALSE,
+ String GetColRowString( bool bAbsolute = false,
const Details& rDetails = detailsOOOa1) const;
};
@@ -399,7 +393,7 @@ inline bool ScAddress::operator!=( const ScAddress& r ) const
inline bool ScAddress::operator<( const ScAddress& r ) const
{
// Same behavior as the old UINT32 nAddress < r.nAddress with encoded
// tab|col|row bit fields.
if (nTab == r.nTab)
{
@@ -487,17 +481,17 @@ public:
inline bool In( const ScAddress& ) const; // is Address& in Range?
inline bool In( const ScRange& ) const; // is Range& in Range?
- USHORT Parse( const String&, ScDocument* = NULL,
+ sal_uInt16 Parse( const String&, ScDocument* = NULL,
const ScAddress::Details& rDetails = ScAddress::detailsOOOa1,
ScAddress::ExternalInfo* pExtInfo = NULL,
const ::com::sun::star::uno::Sequence<
const ::com::sun::star::sheet::ExternalLinkInfo > * pExternalLinks = NULL );
- USHORT ParseAny( const String&, ScDocument* = NULL,
+ sal_uInt16 ParseAny( const String&, ScDocument* = NULL,
const ScAddress::Details& rDetails = ScAddress::detailsOOOa1 );
- SC_DLLPUBLIC USHORT ParseCols( const String&, ScDocument* = NULL,
+ SC_DLLPUBLIC sal_uInt16 ParseCols( const String&, ScDocument* = NULL,
const ScAddress::Details& rDetails = ScAddress::detailsOOOa1 );
- SC_DLLPUBLIC USHORT ParseRows( const String&, ScDocument* = NULL,
+ SC_DLLPUBLIC sal_uInt16 ParseRows( const String&, ScDocument* = NULL,
const ScAddress::Details& rDetails = ScAddress::detailsOOOa1 );
/** Parse an Excel style reference up to and including the sheet name
@@ -521,15 +515,15 @@ public:
bOnlyAcceptSingle==true was given.
*/
const sal_Unicode* Parse_XL_Header( const sal_Unicode* pString, const ScDocument* pDoc,
- String& rExternDocName, String& rStartTabName, String& rEndTabName, USHORT& nFlags,
+ String& rExternDocName, String& rStartTabName, String& rEndTabName, sal_uInt16& nFlags,
bool bOnlyAcceptSingle,
const ::com::sun::star::uno::Sequence<
const ::com::sun::star::sheet::ExternalLinkInfo > * pExternalLinks = NULL );
- SC_DLLPUBLIC void Format( String&, USHORT = 0, ScDocument* = NULL,
+ SC_DLLPUBLIC void Format( String&, sal_uInt16 = 0, ScDocument* = NULL,
const ScAddress::Details& rDetails = ScAddress::detailsOOOa1 ) const;
- SC_DLLPUBLIC void Format( rtl::OUString&, USHORT = 0, ScDocument* = NULL,
+ SC_DLLPUBLIC void Format( rtl::OUString&, sal_uInt16 = 0, ScDocument* = NULL,
const ScAddress::Details& rDetails = ScAddress::detailsOOOa1 ) const;
inline void GetVars( SCCOL& nCol1, SCROW& nRow1, SCTAB& nTab1,
@@ -668,8 +662,8 @@ public:
{ aRange[0] = r1; aRange[1] = r2; }
inline ScRangePair& operator= ( const ScRangePair& r );
- const ScRange& GetRange( USHORT n ) const { return aRange[n]; }
- ScRange& GetRange( USHORT n ) { return aRange[n]; }
+ const ScRange& GetRange( sal_uInt16 n ) const { return aRange[n]; }
+ ScRange& GetRange( sal_uInt16 n ) { return aRange[n]; }
inline int operator==( const ScRangePair& ) const;
inline int operator!=( const ScRangePair& ) const;
};
@@ -399,7 +393,7 @@ inline bool ScAddress::operator!=( const ScAddress& r ) const
inline bool ScAddress::operator<( const ScAddress& r ) const
{
- // Same behavior as the old UINT32 nAddress < r.nAddress with encoded
+ // Same behavior as the old sal_uInt32 nAddress < r.nAddress with encoded
// tab|col|row bit fields.
if (nTab == r.nTab)